(function (window, $, _, Concrete) {
    "use strict";

    var editor = new Concrete.EditMode({notify: false}),
        ConcreteEvent = Concrete.event,
        $currentVariation = null;

    ConcreteEvent.on("AddBlockListAddBlock", function (event, data) {
        var area = editor.getAreaByID($currentVariation.data("area-id")),
            blockType = null;

        if (!data.$launcher.data("btid")) {
            blockType = new Concrete.Stack(data.$launcher, editor);
            $currentVariation.find(".add-block").hide();
        } else {
            blockType = new Concrete.BlockType(data.$launcher, editor);
        }
        blockType.addToDragArea(_.last(area.getDragAreas()));
        return false;
    });

    ConcreteEvent.on('ClipboardAddBlock', function (event, data) {
        var area = editor.getAreaByID($currentVariation.data("area-id")),
            block = new Concrete.DuplicateBlock(data.$launcher, editor);
        block.addToDragArea(_.last(area.getDragAreas()));
        return false;
    });

    ConcreteEvent.on('EditModeAddBlockComplete', function () {
        $currentVariation.find(".add-block").hide();
        Concrete.getEditMode().scanBlocks();
    });

    ConcreteEvent.on('EditModeAddClipboardComplete', function () {
        $currentVariation.find(".add-block").hide();
        Concrete.getEditMode().scanBlocks();
    });

    ConcreteEvent.on('EditModeUpdateBlockComplete', function () {
        Concrete.getEditMode().scanBlocks();
    });

    ConcreteEvent.on('EditModeBlockDelete', function (event, data) {
        $("div[data-area-id='" + data.block.getAreaId() + "']").find(".add-block").show();
        _.defer(function () {
            Concrete.getEditMode().scanBlocks();
        });
    });

    ConcreteEvent.on('EditModeBlockEditInline', function () {
        disableBlockButtons();
    });

    ConcreteEvent.on('EditModeBlockAddInline', function () {
        disableBlockButtons();
    });

    ConcreteEvent.on('EditModeExitInline', function () {
        enableBlockButtons();
    });

    var onAddBlockBtn = function () {
        $currentVariation = $(this).closest(".variation");
    };

    $(".btn-add-block").click(onAddBlockBtn);
    $(".btn-add-stack").click(onAddBlockBtn);

    var openExportValuesDialog = function (e) {
        e.preventDefault();
        $('#territory-export-value').val($("#values").val());
        $('#territory-export').submit();
    };

    var importFile = function (e) {
        e.preventDefault();
        $("#territory-import").submit();
        $('#import-iframe-target').load(function () {
            jQuery.fn.dialog.closeTop();
            var contents = this.contentWindow.document.body.innerHTML;
            if (contents.length > 0) {
                contents = $.parseJSON(contents);
                if (contents.status === 'success') {
                    $("#values").val(contents.message);
                } else {
                    ConcreteAlert.error({message: contents.message});
                }
            }
        });
    };

    var disableBlockButtons = function () {
        $(".add-block").find("a").addClass('disabled');
    };

    var enableBlockButtons = function () {
        $(".add-block").find("a").removeClass('disabled');
    };

    $('#territory-values-export').on('click', openExportValuesDialog);
    $(document).on('click', '.do-import-values', importFile);

}(window, jQuery, _, Concrete));