(function (window, $) {
    "use strict";

    var $territoriesTable = $("#territories-table");

    var moveTerritoryUp = function (e) {
        e.preventDefault();
        var territoryB = $(this).closest(".territory-row");
        var territoryA = $(territoryB).prev(".territory-row:not(.territory-default)");
        if (territoryA.length !== 0) {
            flip(territoryA, territoryB);
        }
    };

    var moveTerritoryDown = function (e) {
        e.preventDefault();
        var territoryA = $(this).closest(".territory-row");
        var territoryB = $(territoryA).next(".territory-row:not(.territory-default)");
        if (territoryB.length !== 0) {
            flip(territoryA, territoryB);
        }
    };

    var flip = function (territoryA, territoryB) {
        var priorityA = $(territoryA).data("priority");
        var priorityB = $(territoryB).data("priority");

        var $newTerritoryB = $(territoryB).clone(true);
        $(territoryB).remove();

        $(territoryA)
            .before($newTerritoryB)
            .data("priority", priorityB);

        $newTerritoryB.data("priority", priorityA);

        var territories = [
            {
                'id': $(territoryA).data("territory"),
                'priority': priorityB
            },
            {
                'id': $(territoryB).data("territory"),
                'priority': priorityA
            }
        ];

        sendTerritoryPriorities(territories);
    };

    var sendTerritoryPriorities = function (territories) {
        jQuery.fn.dialog.showLoader();
        $.ajax(window.CCM_DISPATCHER_FILENAME + "/package/geo_content/territory_utilities/save_priorities", {
            type: 'POST',
            contentType: 'application/json',
            dataType: 'json',
            data: JSON.stringify({
                'territories': territories,
                'ccmToken': window.CCM_SECURITY_TOKEN
            }),
            complete: function () {
                jQuery.fn.dialog.hideLoader();
            }
        });
    };

    var moveTerritoryTop = function (e) {
        e.preventDefault();

        var territoryToMove = $(this).closest(".territory-row");
        var newTerritory = territoryToMove.clone(true).data("priority", "0");

        var territories = [
            {
                id: newTerritory.data("territory"),
                priority: 0
            }
        ];

        $(territoryToMove).prevAll('.territory-row').each(function () {
            $(this).data("priority", $(this).data("priority") + 1);
            territories.push({
                id: $(this).data("territory"),
                priority: $(this).data("priority")
            });
        });

        sendTerritoryPriorities(territories);

        territoryToMove.remove();
        newTerritory.prependTo($territoriesTable);
    };

    var moveTerritoryBottom = function (e) {
        e.preventDefault();

        var territoryToMove = $(this).closest(".territory-row");
        var lastTerritory = $territoriesTable.find(".territory-row:not(.territory-default):last");
        if (!lastTerritory.is(territoryToMove)) {
            var newPriority = lastTerritory.data("priority");
            var newTerritory = territoryToMove.clone(true).data("priority", newPriority);

            var territories = [
                {
                    id: newTerritory.data("territory"),
                    priority: newPriority
                }
            ];

            $(territoryToMove).nextAll('.territory-row').not('.territory-default').each(function () {
                $(this).data("priority", $(this).data("priority") - 1);
                territories.push({
                    id: $(this).data("territory"),
                    priority: $(this).data("priority")
                });
            });

            sendTerritoryPriorities(territories);

            territoryToMove.remove();
            $territoriesTable.find(".territory-row:last").before(newTerritory);
        }
    };

    var bulkActions = function (e) {
        switch ($(this).val()) {
            case 'delete':
                if (confirm(window.GEO_CONTENT_BULK_DELETE)) {
                    jQuery.fn.dialog.showLoader();

                    $("#territories-check-all").prop("checked", false);

                    var territories = [];
                    $territoriesTable.find(".bulk-checkbox:checked").each(function () {
                        var $territory = $(this).closest('.territory-row');
                        territories.push({
                            id: $territory.data("territory"),
                            name: $territory.find(".territory-name").text(),
                            row: $territory
                        });
                    });

                    var newPriorities = [],
                        toDelete = [];

                    for (var i = 0; i < territories.length; i++) {
                        var territory = territories[i];
                        toDelete.push(territory.id);
                        $(territory.row).remove();
                    }

                    $.ajax(window.CCM_DISPATCHER_FILENAME + "/package/geo_content/territory_utilities/delete_territories", {
                        type: 'POST',
                        contentType: 'application/json',
                        dataType: 'json',
                        data: JSON.stringify({
                            'territories': toDelete,
                            'ccmToken': window.CCM_SECURITY_TOKEN
                        })
                    });

                    // now recalc priorities
                    $territoriesTable.find(".territory-row:not(.territory-default)").each(function (index) {
                        $(this).data("priority", index);
                        newPriorities.push({
                            id: $(this).data("territory"),
                            priority: index
                        });
                    });
                    sendTerritoryPriorities(newPriorities);
                }
                break;
        }

        $(this).val("");
    };

    var checkAllTerritories = function () {
        var checked = $(this).is(":checked");
        $territoriesTable.find(".bulk-checkbox").prop('checked', checked);
    };

    var sortByName = function (e) {
        e.preventDefault();
        var territories = $territoriesTable.find(".territory-row:not(.territory-default)").toArray();
        territories.sort(function (a, b) {
            var aName = $(a).find(".territory-name").text();
            var bName = $(b).find(".territory-name").text();

            if (aName > bName) {
                return 1;
            } else if (aName < bName) {
                return -1;
            } else {
                return 0;
            }
        }).reverse();

        var territoriesToUpdate = [];

        $(territories).each(function (newPriority) {
            $(this).data("priority", territories.length - newPriority);
            territoriesToUpdate.push({
                'id': $(this).data("territory"),
                'priority': territories.length - newPriority
            });
            $territoriesTable.prepend(this);
        });

        sendTerritoryPriorities(territoriesToUpdate);
    };


    $(".move-territory-up").click(moveTerritoryUp);
    $(".move-territory-down").click(moveTerritoryDown);
    $(".move-territory-top").click(moveTerritoryTop);
    $(".move-territory-bottom").click(moveTerritoryBottom);
    $("#territories-check-all").click(checkAllTerritories);
    $(".bulk-actions").change(bulkActions);
    $("#sort-territories-by-name").click(sortByName);

}(window, jQuery));
