<?php 
namespace Concrete\Package\GeoContent\Block\DisplayByLocale;

use Area;
use Block;
use Concrete\Core\Block\BlockController;
use Concrete\Core\Utility\IPAddress;
use Concrete\Package\GeoContent\Src\Models\Territory;
use Core;
use Database;
use Doctrine\ORM\NoResultException;
use Stack;

class Controller extends BlockController
{

    public $btTable = 'GeoContentBtDisplayByLocale';

    public $btCacheBlockRecord = true;
    public $btCacheBlockOutput = false;

    const SORT_QUERY = 1;
    const SORT_ALPHABETICAL = 2;

    public function getBlockTypeName()
    {
        return t('Display by Locale');
    }

    public function getBlockTypeDescription()
    {
        return t('Display a block based on the user\'s geographical location.');
    }

    public function save($args)
    {
        if ($args['territoryDropdown'] === null) {
            $args['territoryDropdown'] = 0;
        }

        parent::save($args);
    }

    public function validate($args)
    {
        $e = \Core::make('error');
        if (!$args['variationID']) {
            $e->add(t('You must specify a display variation.'));
        }
        return $e;
    }

    public function view()
    {
        $ip = Core::make('ip')->getRequestIP()->getIp(IPAddress::FORMAT_IP_STRING);
        $em = Database::connection()->getEntityManager();;
        $block = null;
        $area = null;
        $activeTerritory = null;
        $db = $em->createQueryBuilder();

        if (\Cookie::has('geoContentTerritoryPriority')) {
            // user has picked a preferred territory, try to get a block for it
            try {
                $queryParameters = array(
                    ':vid' => $this->variationID, ':tid' => \Cookie::get('geoContentTerritoryPriority')
                );
                $result = $db->select(
                    array('territory.id', 'territoryVariation.blockID', 'variation.id AS variationID')
                )
                    ->from('Concrete\Package\GeoContent\Src\Models\TerritoryVariation', 'territoryVariation')
                    ->innerJoin('territoryVariation.territory', 'territory')
                    ->innerJoin('territoryVariation.variation', 'variation')
                    ->leftJoin('territory.values', 'value')
                    ->where($db->expr()->andX(
                        $db->expr()->eq('territory.id', ':tid'),
                        $db->expr()->eq('territoryVariation.variation', ':vid'),
                        $db->expr()->isNotNull('territoryVariation.blockID')
                    ))
                    ->setMaxResults(1)
                    ->setParameters($queryParameters)
                    ->getQuery()->getSingleResult();
                $activeTerritory = Territory::findByID($result['id']);
                $stack = Stack::getByID($activeTerritory->stackID, 'ACTIVE');
                $area = Area::get($stack, 'variation' . $result['variationID']);
                $block = Block::getByID(
                    $result['blockID'],
                    $stack,
                    $area
                );
            } catch (NoResultException $e) {
            }
        }

        if ($block === null) {
            if (\Cookie::has('geoContentLocation')) {
                // we have the location cached
                $location = unserialize(\Cookie::get('geoContentLocation'));
            } else {
                // find the location and store it in a cookie
                $locationResolver = Core::make('geo_content/resolver');
                $location = $locationResolver->getLocation($ip);
                \Cookie::set('geoContentLocation', serialize($location), time() + 365 * 3600 * 24);
            }

            $queryParameters = array(':vid' => $this->variationID);
            $locationWhere = array();
            foreach ($location as $field => $value) {
                if ($value !== null) {
                    $locationWhere[] = $db->expr()->andX(
                        $db->expr()->eq('territory.column', ':tc' . $field),
                        $db->expr()->eq('value.value', ':tv' . $field)
                    );

                    $queryParameters[':tc' . $field] = $field;
                    $queryParameters[':tv' . $field] = $value;
                }
            }

            $locationWhere = call_user_func_array(array($db->expr(), 'orX'), $locationWhere);

            try {
                $db = $em->createQueryBuilder();
                $result = $db
                    ->select(
                        array('territory.id', 'territoryVariation.blockID', 'variation.id AS variationID')
                    )
                    ->from('Concrete\Package\GeoContent\Src\Models\TerritoryVariation', 'territoryVariation')
                    ->innerJoin('territoryVariation.territory', 'territory')
                    ->innerJoin('territoryVariation.variation', 'variation')
                    ->leftJoin('territory.values', 'value')
                    ->where($db->expr()->andX(
                        $db->expr()->orX(
                            $locationWhere,
                            $db->expr()->eq('territory.default', 1)
                        ),
                        $db->expr()->eq('territoryVariation.variation', ':vid'),
                        $db->expr()->isNotNull('territoryVariation.blockID')
                    ))
                    ->orderBy('territory.default', 'ASC')
                    ->addOrderBy('territory.priority', 'ASC')
                    ->setMaxResults(1)
                    ->setParameters($queryParameters)
                    ->getQuery()->getSingleResult();
                $activeTerritory = Territory::findByID($result['id']);
                $stack = Stack::getByID($activeTerritory->stackID, 'ACTIVE');
                $area = Area::get($stack, 'variation' . $result['variationID']);
                $block = Block::getByID(
                    $result['blockID'],
                    $stack,
                    $area
                );
            } catch (NoResultException $e) {
            }
        }

        if ($this->territoryDropdown) {
            $db = $em->createQueryBuilder();
            $db
                ->select(array('territory.id', 'territory.name'))
                ->from('Concrete\Package\GeoContent\Src\Models\TerritoryVariation', 'territoryVariation')
                ->innerJoin('territoryVariation.territory', 'territory')
                ->where($db->expr()->andX(
                    $db->expr()->eq('territoryVariation.variation', ':vid'),
                    $db->expr()->eq('territory.default', 0),
                    $db->expr()->isNotNull('territoryVariation.blockID')
                ))
                ->setParameters(array(':vid' => $this->variationID));

            if ($this->sort === (string)self::SORT_QUERY) {
                $db->orderBy('territory.priority', 'ASC');
            } else if ($this->sort === (string)self::SORT_ALPHABETICAL) {
                $db->orderBy('territory.name', 'ASC');
            }

            $territories = $db->getQuery()->getResult();

            $this->set('territories', $territories);
        }

        $this->set('block', $block);
        $this->set('area', $area);
        $this->set('activeTerritory', $activeTerritory);
    }

}
