<?php 

namespace Concrete\Package\GeoContent;

use AssetList;
use BlockType;
use Concrete\Core\Foundation\Service\ProviderList;
use Concrete\Package\GeoContent\Src\Models\Resolver;
use Concrete\Package\GeoContent\Src\Models\Territory;
use Core;
use Events;
use Package;
use Route;
use SinglePage;
use Stack;

class Controller extends Package
{

    protected $pkgHandle = 'geo_content';
    protected $appVersionRequired = '5.7.5';
    protected $pkgVersion = '0.9.7';

    public function getPackageName()
    {
        return t('Geo Content');
    }

    public function getPackageDescription()
    {
        return t('Allows for geo-targeting of blocks');
    }

    public function install()
    {
        $pkg = parent::install();
        SinglePage::add('/dashboard/geo_content', $pkg);
        SinglePage::add('/dashboard/geo_content/variations', $pkg);
        $sp = SinglePage::add('/dashboard/geo_content/variations/add', $pkg);
        $sp->setAttribute('exclude_nav', true);
        $sp->updateCollectionName(t('Add Variation'));
        $sp = SinglePage::add('/dashboard/geo_content/variations/edit', $pkg);
        $sp->setAttribute('exclude_nav', true);
        $sp->updateCollectionName(t('Edit Variation'));
        SinglePage::add('/dashboard/geo_content/territories', $pkg);
        $sp = SinglePage::add('/dashboard/geo_content/territories/add', $pkg);
        $sp->setAttribute('exclude_nav', true);
        $sp->updateCollectionName(t('Add Territory'));
        $sp = SinglePage::add('/dashboard/geo_content/territories/edit', $pkg);
        $sp->setAttribute('exclude_nav', true);
        $sp->updateCollectionName(t('Edit Territory'));
        SinglePage::add('/dashboard/geo_content/resolvers', $pkg);

        Resolver::install('\Concrete\Package\GeoContent\Src\Resolver\IpInfoResolver');
        Resolver::setActive('ip_info');

        BlockType::installBlockType('display_by_locale', $pkg);

        $defaultTerritory = Territory::findOneBy(array('default' => true));
        if (!$defaultTerritory) {
            $defaultTerritory = new Territory();
            $defaultTerritory->name = t('Global');
            $defaultTerritory->stackID = Stack::addStack(t('Geo Content: %s', 'Global'))->getCollectionID();
            $defaultTerritory->default = true;
            $defaultTerritory->priority = 0;
            $defaultTerritory->save();
        }
    }

    public function uninstall()
    {
        Resolver::uninstall('ip_info');
        parent::uninstall();
    }

    public function on_start()
    {
        $this->registerAssets();
        $this->registerEvents();
        $this->registerProviders();
        $this->registerRoutes();
    }

    private function registerAssets()
    {
        $assetList = AssetList::getInstance();
        $assetList->register(
            'javascript',
            'geo_content/territory_form',
            'assets/js/territory_form.js',
            array(),
            'geo_content'
        );
        $assetList->registerGroup(
            'geo_content/territory_form',
            array(
                array('javascript', 'jquery'),
                array('javascript', 'underscore'),
                array('javascript', 'geo_content/territory_form')
            )
        );
        $assetList->register(
            'javascript',
            'geo_content/territory_list',
            'assets/js/territory_list.js',
            array(),
            'geo_content'
        );
        $assetList->registerGroup(
            'geo_content/territory_list',
            array(
                array('javascript', 'jquery'),
                array('javascript', 'geo_content/territory_list')
            )
        );
        $assetList->register(
            'javascript',
            'geo_content/variation_list',
            'assets/js/variation_list.js',
            array(),
            'geo_content'
        );
        $assetList->registerGroup(
            'geo_content/variation_list',
            array(
                array('javascript', 'jquery'),
                array('javascript', 'geo_content/variation_list')
            )
        );
        $assetList->register(
            'javascript',
            'geo_content/resolver_form',
            'assets/js/resolver_form.js',
            array(),
            'geo_content'
        );
        $assetList->registerGroup(
            'geo_content/resolver_form',
            array(
                array('javascript', 'jquery'),
                array('javascript', 'geo_content/resolver_form')
            )
        );
    }

    private function registerEvents()
    {
        Events::addListener(
            'on_page_version_approve',
            array('\Concrete\Package\GeoContent\Src\Events\PageVersion', 'onApprove')
        );
    }

    private function registerProviders()
    {
        $providers = new ProviderList(Core::getFacadeRoot());
        $providers->registerProvider('Concrete\Package\GeoContent\Src\Resolver\ResolverServiceProvider');
    }

    private function registerRoutes()
    {
        Route::register(
            '/package/geo_content/territory_utilities/save_priorities',
            '\Concrete\Package\GeoContent\Controller\TerritoryUtilities::savePriorities',
            'GeoContentTerritoryPriority'
        );

        Route::register(
            '/package/geo_content/territory_utilities/import_values',
            '\Concrete\Package\GeoContent\Controller\TerritoryUtilities::importValues',
            'GeoContentTerritoryImportValues'
        );

        Route::register(
            '/package/geo_content/dialog/import_values',
            '\Concrete\Package\GeoContent\Controller\Dialog\ImportValues::view',
            'GeoContentTerritoryImportDialog'
        );

        Route::register(
            '/package/geo_content/territory_utilities/export_values',
            '\Concrete\Package\GeoContent\Controller\TerritoryUtilities::exportValues',
            'GeoContentTerritoryExportValues'
        );

        Route::register(
            '/package/geo_content/territory_utilities/delete_territories',
            '\Concrete\Package\GeoContent\Controller\TerritoryUtilities::deleteTerritories',
            'GeoContentTerritoryDeleteTerritories'
        );

        Route::register(
            '/package/geo_content/territory_utilities/delete_variations',
            '\Concrete\Package\GeoContent\Controller\TerritoryUtilities::deleteVariations',
            'GeoContentTerritoryDeleteVariations'
        );

        Route::register(
            '/package/geo_content/dialog/add_stack_list',
            '\Concrete\Package\GeoContent\Controller\Dialog\AddStackList::view',
            'GeoContentTerritoryAddStackListDialog'
        );
    }

}
