<?php 
namespace Concrete\Package\GeoContent\Controller\SinglePage\Dashboard\GeoContent\Territories;

use CollectionVersion;
use Concrete\Core\Page\Controller\DashboardPageController;
use Concrete\Package\GeoContent\Src\Form\ValidationException;
use Concrete\Package\GeoContent\Src\Models\Territory;
use Concrete\Package\GeoContent\Src\Models\Variation;
use Core;
use Stack;

class Edit extends DashboardPageController
{

    public function view($id)
    {
        if ($this->get('new')) {
            $this->set('message', t('The territory was successfully created. You can now add content to variations.'));
        }

        $territory = Territory::findByID($id);

        if (!$territory) {
            $this->redirect('/dashboard/geo_content/territories');
        }

        $variations = Variation::findBy(array());

        if (!\Collection::getByID($territory->stackID)->getCollectionID()) {
            $territory->removeTerritoryVariations();
            $stack = Stack::addStack(t('Geo Content: %s', $territory->name));
            $territory->stackID = $stack->getCollectionID();
            $territory->save();
        } else {
            $stack = Stack::getByID($territory->stackID);
        }

        if ($this->post() != null && Core::make('helper/validation/token')->validate('territory_form')) {
            $territory->name = trim($this->post('name'));
            $territory->column = $this->post('column');

            $territory->updateValues(explode(',', $this->post('values')));

            try {
                $territory->save();
                $version = CollectionVersion::get($stack, 'RECENT');
                $version->approve();

                $this->redirect('/dashboard/geo_content/territories?success=saved');
            } catch (ValidationException $e) {
                $e->setCoreErrors($this->error);
            }
        }

        $territoryVariations = array();
        foreach ($territory->variations as $territoryVariation) {
            $territoryVariations[$territoryVariation->variation->id] = $territoryVariation;
        }

        $approved = $stack->getVersionID() === CollectionVersion::get($stack, 'ACTIVE')->getVersionID();

        $resolverColumns = Core::make('geo_content/resolver')->getFields();

        $this->set('territory', $territory);
        $this->set('variations', $variations);
        $this->set('territoryVariations', $territoryVariations);
        $this->set('stack', $stack);
        $this->set('approved', $approved);
        $this->set('resolverColumns', $resolverColumns);
    }

}