<?php 

namespace Concrete\Package\GeoContent\Controller;

use Concrete\Core\Controller\Controller;
use Concrete\Package\GeoContent\Src\Models\Territory;
use Concrete\Package\GeoContent\Src\Models\Variation;
use Core;

class TerritoryUtilities extends Controller
{

    public function savePriorities()
    {
        $page = \Page::getByPath('/dashboard/geo_content/territories/edit');
        $permissions = new \Permissions($page);
        $json = json_decode(file_get_contents('php://input'), true);
        if ($permissions->canViewPage() && Core::make('token')->validate('', $json['ccmToken'])) {
            foreach ($json['territories'] as $territory) {
                $territoryModel = Territory::findByID($territory['id']);
                $territoryModel->priority = $territory['priority'];
                $territoryModel->save();
            }
        } else {
            echo t('Permission denied');
        }
    }

    public function importValues()
    {
        $response = null;
        if (isset($_FILES) && Core::make('token')->validate('territory_import')) {
            try {
                $values = array();
                foreach ($_FILES as $file) {
                    $csvFile = fopen($file['tmp_name'], 'r');
                    while (!feof($csvFile)) {
                        $valueArr = fgetcsv($csvFile);
                        if (is_array($valueArr)) {
                            foreach ($valueArr AS $value) {
                                $values[] = $value;
                            }
                        }
                    }
                    fclose($csvFile);
                }
                $response = json_encode(
                    array(
                        'status' => 'success',
                        'message' => implode(',', $values)
                    )
                );
            } catch (\Exception $e) {
                $response = false;
            }
        } else {
            $response = json_encode(
                array(
                    'status' => 'fail',
                    'message' => t('An invalid token or file was provided.'),
                )

            );
        }

        if ($response) {
            echo $response;
        } else {
            echo json_encode(
                array(
                    'status' => 'fail',
                    'message' => t('An invalid file provided. Only CSV files are supposed.'),
                )
            );
        }
    }

    public function exportValues()
    {
        if ($this->post('values', false) !== false && Core::make('token')->validate('territory_export')) {
            $values = array_map('trim', explode(',', $this->post('values')));
            ob_clean();
            header('Pragma: public');
            header('Expires: 0');
            header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
            header('Cache-Control: private', false);
            header('Content-Type: text/csv');
            header('Content-Disposition: attachment;filename=territory_values_export_' . date('YmdHis') . '.csv');
            $fp = fopen('php://output', 'w');
            fputcsv($fp, $values);
            fclose($fp);
            ob_flush();
        } else {
            echo t('Invalid token or values');
        }
    }

    public function deleteTerritories()
    {
        $page = \Page::getByPath('/dashboard/geo_content/territories');
        $permissions = new \Permissions($page);
        $json = json_decode(file_get_contents('php://input'), true);
        if ($permissions->canViewPage() && Core::make('token')->validate('', $json['ccmToken'])) {
            foreach ($json['territories'] as $territoryId) {
                $territory = Territory::findByID($territoryId);
                if ($territory) {
                    $territory->delete();
                }
            }
        }
    }

    public function deleteVariations()
    {
        $page = \Page::getByPath('/dashboard/geo_content/variations');
        $permissions = new \Permissions($page);
        $json = json_decode(file_get_contents('php://input'), true);
        if ($permissions->canViewPage() && Core::make('token')->validate('', $json['ccmToken'])) {
            foreach ($json['variations'] as $variationId) {
                $variation = Variation::findByID($variationId);
                if ($variation) {
                    $variation->delete();
                }
            }
        }
    }

}