<?php 
defined('C5_EXECUTE') or die('Access denied.');

use Concrete\Core\Http\ResponseAssetGroup;


$form = Core::make('helper/form');
/** @var Concrete\Package\GeoContent\Src\Models\Territory $territory */
/** @var Concrete\Package\GeoContent\Src\Models\Variation[] $variations */
/** @var Concrete\Package\GeoContent\Src\Models\TerritoryVariation[] $territoryVariations */
/** @var  \Stack $stack */
/** @var boolean $isNew */
/** @var bool $approved */
/** @var array $resolverColumns */

$r = ResponseAssetGroup::get();
$r->requireAsset('dashboard');
$r->requireAsset('geo_content/territory_form');

if ($territory->default) {
    $nameParams = array('readonly' => 'readonly');
} else {
    $nameParams = array();
}
?>

<form method="post" class="territory-detail">
    <?php echo  Core::make('helper/validation/token')->output('territory_form') ?>

    <div class="form-group">
        <?php echo  $form->label('name', t('Name')) ?>
        <?php echo  $form->text('name', $territory->name, $nameParams) ?>
    </div>

    <?php 
    if (!$territory->default) {
        ?>
        <fieldset>
            <legend><?php echo  t('Auto-Detect Selection') ?></legend>

            <div class="form-group">
                <?php echo  $form->label('column', t('Column')) ?>
                <?php echo  $form->select('column', $resolverColumns, $territory->column) ?>
            </div>

            <div class="form-group">
                <?php echo  $form->label('values', t('Values')) ?>
                <div>
                    <div style="float: right">
                        <div class="btn-group-vertical">
                            <button id="territory-values-export" type="button" class="btn btn-primary"
                                    style="border-bottom-left-radius: 0; border-top-left-radius: 0">
                                <?php echo  t('Export CSV') ?>
                            </button>
                            <a href="<?php echo  URL::to('/package/geo_content/dialog/import_values') ?>"
                               class="dialog-launch btn btn-primary" dialog-width="500" dialog-height="150"
                               dialog-modal="true" dialog-title="<?php echo  t('Import CSV') ?>"
                               style="border-bottom-left-radius: 0; border-top-left-radius: 0">
                                <?php echo  t('Import CSV') ?>
                            </a>
                        </div>
                    </div>
                    <div style="overflow: hidden">
                        <?php 
                        echo $form->textarea(
                            'values',
                            implode(', ', $territory->getValuesArray()),
                            array('style' => 'border-bottom-right-radius: 0; border-top-right-radius: 0; height: 67px')
                        );
                        ?>
                    </div>
                </div>
            </div>
        </fieldset>
        <?php 
    }
    ?>

    <fieldset>
        <legend><?php echo  t('Display Variations') ?></legend>
        <?php 
        if ($isNew) {
            ?>
            <div class="alert alert-warning"><?php echo  t('You must first save this territory to add variations.') ?></div>
            <?php 
        } else {
            if (!$approved) {
                ?>
                <div class="alert alert-warning">
                    <?php echo  t(
                        'There are unapproved changes in these variations. Save the territory to approve.'
                    ) ?>
                </div>
                <?php 
            }

            if (empty($variations)) {
                ?>
                <div class="alert alert-warning">
                    <?php echo  t(
                        'You must first <a href="%s">create a variation</a>.',
                        URL::to('/dashboard/geo_content/variations/add')
                    ) ?>
                </div>
                <?php 
            }

            foreach ($variations as $variation) {
                View::element(
                    'territory_variation',
                    array(
                        'territory' => $territory,
                        'variation' => $variation,
                        'stack' => $stack,
                        'territoryVariation' => (isset($territoryVariations[$variation->id]) ? $territoryVariations[$variation->id] : null)
                    ),
                    'geo_content'
                );
                if ($variation !== end($variations)) {
                    echo '<hr/>';
                }
            }
        }
        ?>
    </fieldset>

    <div class="ccm-dashboard-form-actions-wrapper" style="z-index: 500">
        <div class="ccm-dashboard-form-actions">
            <a href="<?php echo  URL::to('/dashboard/geo_content/territories') ?>" class="btn btn-default pull-left">
                <?php echo  t('Cancel') ?>
            </a>
            <button type="submit" class="btn btn-primary pull-right"><?php echo  t('Save') ?></button>
        </div>
    </div>
</form>

<form id="territory-export" class="hidden" method="post"
      action="<?php echo  Url::to('/package/geo_content/territory_utilities/export_values') ?>">
    <?php echo  Core::make('helper/validation/token')->output('territory_export') ?>
    <input id="territory-export-value" type="hidden" name="values"/>
</form>
