<?php 

namespace Concrete\Package\GeoContent\Src\Models;

use Database;

/**
 * Basic model support that makes interacting with doctrine entities nicer
 * @MappedSuperclass
 * @HasLifecycleCallbacks
 */
class BaseEntity
{

    protected $entityManager;

    public function __construct()
    {
        $this->init();
    }

    /**
     * When overriding this method in extended classes you should always call its parent function. The BaseEntity calls
     * this function on construct and as such the __construct function should be avoided in other entity classes which
     * extend this class
     * @PostLoad
     */
    public function init()
    {
        $this->entityManager = Database::connection()->getEntityManager();
    }


    /**
     * Returns the entity manager
     * @return \Doctrine\ORM\EntityManager
     */
    public function getEntityManager()
    {
        return $this->entityManager;
    }

    /**
     * Persists the current object and flushes the entity manager for that object
     */
    public function save()
    {
        $this->getEntityManager()->persist($this);
        $this->getEntityManager()->flush();
    }

    /**
     * Removes the current object and flushes the entity manager for that object
     */
    public function delete()
    {
        $this->getEntityManager()->remove($this);
        $this->getEntityManager()->flush();
    }

    /**
     * Finds an entity by ID
     * @param $id
     * @return static Returns static if the object is found or null if it does not exist
     */
    public static function findByID($id)
    {
        $entity = new static();
        return $entity->getEntityManager()->find(get_class($entity), $id);
    }

    /**
     * Finds an entity by a given criteria
     * @param $criteria
     * @param null $orderBy
     * @param null $limit
     * @param null $offset
     * @return static[]
     */
    public static function findBy($criteria, $orderBy = null, $limit = null, $offset = null)
    {
        $entity = new static();
        $repository = $entity->getEntityManager()->getRepository(get_Class($entity));
        return $repository->findBy($criteria, $orderBy, $limit, $offset);
    }

    /**
     * Finds one entity by the given criteria
     * @param $criteria
     * @return static
     */
    public static function findOneBy($criteria)
    {
        $entity = new static();
        $repository = $entity->getEntityManager()->getRepository(get_Class($entity));
        return $repository->findOneBy($criteria);
    }
} 