<?php 

namespace Concrete\Package\GeoContent\Src\Models;

use Concrete\Package\GeoContent\Src\Resolver\ResolverInterface;
use Database;

/**
 * @Entity
 * @Table(
 *  name="GeoContentResolvers"
 * )
 */
class Resolver extends BaseEntity
{

    /**
     * @Id
     * @Column(name="resolverID", type="integer")
     * @GeneratedValue
     */
    public $id;
    /** @Column(name="resolverHandle", length=255, unique=true) */
    public $handle;
    /** @Column(name="resolverName", length=255) */
    public $name;
    /** @Column(name="resolverIsActive", type="boolean") */
    public $isActive;
    /** @Column(name="resolverClass", length=255) */
    public $class;

    /**
     * @return null|self
     */
    public static function getActive()
    {
        $em = Database::connection()->getEntityManager();
        return $em->getRepository('Concrete\Package\GeoContent\Src\Models\Resolver')
            ->findOneBy(array('isActive' => true));
    }

    /**
     * Sets the active resolver
     * @param string $handle
     */
    public static function setActive($handle)
    {
        $em = Database::connection()->getEntityManager();
        $em->createQuery('UPDATE Concrete\Package\GeoContent\Src\Models\Resolver r SET r.isActive = 0')->execute();
        /** @var Resolver $resolver */
        $resolver = $em->getRepository('Concrete\Package\GeoContent\Src\Models\Resolver')
            ->findOneBy(array('handle' => $handle));
        $resolver->isActive = true;
        $resolver->save();
    }

    /**
     * Installs a new resolver
     * @param string $class Full name of the class implementing the resolver interface
     */
    public static function install($class)
    {
        /** @var ResolverInterface $resolverClass */
        $resolverClass = new $class;
        $resolver = new self;
        $resolver->handle = $resolverClass->getHandle();
        $resolver->name = $resolverClass->getName();
        $resolver->isActive = 0;
        $resolver->class = get_class($resolverClass);
        $resolver->save();
    }

    /**
     * Removes a resolver
     * @param string $handle Handle of the resolver to remove
     */
    public static function uninstall($handle)
    {
        $em = Database::connection()->getEntityManager();
        /** @var Resolver $resolver */
        $resolver = $em->getRepository('Concrete\Package\GeoContent\Src\Models\Resolver')
            ->findOneBy(array('handle' => $handle));
        if ($resolver) $resolver->delete();
    }

}