<?php 

namespace Concrete\Package\GeoContent\Src\Models;

use Database;

/**
 * @Entity
 * @Table(
 *  name="GeoContentTerritoryVariations",
 *  indexes={
 *      @Index(name="territory_variation_block", columns={"blockID"})
 *  }
 * )
 */
class TerritoryVariation extends BaseEntity
{

    /**
     * @Id
     * @Column(name="territoryVariationID", type="integer")
     * @GeneratedValue
     */
    public $id;
    /**
     * @ManyToOne(targetEntity="Territory", inversedBy="variations", cascade={"persist"})
     * @JoinColumn(name="territoryID", referencedColumnName="territoryID", nullable=false)
     */
    public $territory;
    /**
     * @ManyToOne(targetEntity="Variation", inversedBy="territoryVariations", cascade={"persist"})
     * @JoinColumn(name="variationID", referencedColumnName="variationID", nullable=false)
     */
    public $variation;
    /** @Column(type="integer") */
    public $blockID = 0;

    /**
     * Returns the most recent block from this territory variation's area
     * @return null|int
     * @throws \Doctrine\DBAL\DBALException
     */
    public function getActiveBlockID()
    {
        $bid = Database::connection()->executeQuery(
            'SELECT bID
            FROM CollectionVersionBlocks cvb
                INNER JOIN CollectionVersions cv
                    ON cvb.cID = cv.cID AND cvb.cvID = cv.cvID AND cv.cvIsApproved = 1
            WHERE cvb.cID = :collection AND cvb.arHandle = :area
            LIMIT 1',
            array(':collection' => $this->territory->stackID, ':area' => $this->variation->getAreaHandle())
        )->fetchColumn();

        if ($bid !== false) {
            return $bid;
        } else {
            return null;
        }
    }

    /**
     * Returns the active block from this territory variation's area
     * @return bool|null|string
     * @throws \Doctrine\DBAL\DBALException
     */
    public function getRecentBlockID()
    {
        $bid = Database::connection()->executeQuery(
            'SELECT bID
            FROM CollectionVersionBlocks cvb
                INNER JOIN CollectionVersions cv
                    ON cvb.cID = cv.cID AND cvb.cvID = cv.cvID
            WHERE cvb.cID = :collection AND cvb.arHandle = :area
            ORDER BY cvb.cvID DESC
            LIMIT 1',
            array(':collection' => $this->territory->stackID, ':area' => $this->variation->getAreaHandle())
        )->fetchColumn();

        if ($bid !== false) {
            return $bid;
        } else {
            return null;
        }
    }

    /**
     * @param Territory $territory
     */
    public function setTerritory($territory)
    {
        $territory->variations->add($this);
        $this->territory = $territory;
    }

    /**
     * @param Variation $variation
     */
    public function setVariation($variation)
    {
        $variation->territoryVariations->add($this);
        $this->variation = $variation;
    }

}