<?php 

namespace Concrete\Package\GeoContent\Src\Models;

use Concrete\Package\GeoContent\Src\Form\ValidationException;

/**
 * @Entity
 * @HasLifecycleCallbacks
 * @Table(name="GeoContentVariations")
 */
class Variation extends BaseEntity
{

    /**
     * @Id
     * @Column(name="variationID", type="integer")
     * @GeneratedValue
     */
    public $id;

    /** @Column(name="variationName", length=255) */
    public $name;

    /**
     * @OneToMany(targetEntity="TerritoryVariation", mappedBy="variation", cascade={"persist"})
     * @var TerritoryVariation[]
     */
    public $territoryVariations;

    /**
     * Validates the entity
     * @PrePersist
     * @PreUpdate
     */
    public function validate()
    {
        $errors = array();
        if (empty($this->name)) {
            $errors[] = t('A variation name must be provided.');
        }

        $existing = self::findOneBy(array('name' => $this->name));
        if ($existing && $existing->id !== $this->id) {
            $errors[] = t('The variation name must be unique.');
        }

        if (!empty($errors)) {
            throw new ValidationException($errors);
        }
    }

    /**
     * @PreRemove
     */
    public function onBeforeDelete()
    {
        foreach ($this->territoryVariations AS $territoryVariation) {
            $territoryVariation->delete();
        }
    }

    public function getAreaHandle()
    {
        return 'variation' . $this->id;
    }

}