<?php 

namespace Concrete\Package\GeoContent\Src\Resolver;


use Config;

class IpInfoResolver extends BaseResolver
{

    /**
     * Returns the handle of the location resolver
     * @return string
     */
    public function getHandle()
    {
        return 'ip_info';
    }

    /**
     * Returns the location resolver name
     * @return string
     */
    public function getName()
    {
        return 'ipinfo.io';
    }

    /**
     * Returns an array of fields that this location resolver provides. For example, one might return
     * array('zip', 'state', 'country') if zip, state, and country can be identified by the location resolver.
     * @return array
     */
    public function getFields()
    {
        return array(
            'region' => 'Region',
            'country' => 'Country',
            'postal' => 'Postal'
        );
    }

    /**
     * Returns an array with the location for the provided IP address. The array returned should use the field as the
     * index and the data as the values. All fields returned by getFields() should be returned by this function.
     *
     * For example, this function might return array('zip' => '53222', 'state' => 'WI', 'country' => 'United States')
     *
     * @param string $ipAddress IP address to lookup location for
     * @return array|false
     */
    public function getLocation($ipAddress)
    {
        $result = false;

        $ch = curl_init('http://ipinfo.io/' . urlencode($ipAddress));
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Accept: application/json'));

        if (Config::get('concrete.proxy.host') != null) {
            @curl_setopt($ch, CURLOPT_PROXY, Config::get('concrete.proxy.host'));
            @curl_setopt($ch, CURLOPT_PROXYPORT, Config::get('concrete.proxy.port'));
            // Check if there is a username/password to access the proxy
            if (Config::get('concrete.proxy.user') != null) {
                @curl_setopt(
                    $ch,
                    CURLOPT_PROXYUSERPWD,
                    Config::get('concrete.proxy.user') . ':' . Config::get('concrete.proxy.password'));
            }
        }

        if ($response = curl_exec($ch)) {
            $json = json_decode($response, true);
            if ($json !== null) {
                $result = array(
                    'region' => $json['region'],
                    'country' => $json['country'],
                    'postal' => $json['postal']
                );
            }
        }

        return $result;
    }

}