<?php 

namespace Concrete\Package\GeoContent\Src\Resolver;


interface ResolverInterface
{

    /**
     * Returns the handle of the location resolver
     * @return string
     */
    public function getHandle();

    /**
     * Returns the location resolver name
     * @return string
     */
    public function getName();

    /**
     * Returns an array of fields that this location resolver provides. For example, one might return
     * array('zip', 'state', 'country') if zip, state, and country can be identified by the location resolver.
     * @return array
     */
    public function getFields();

    /**
     * Returns an array with the location for the provided IP address. The array returned should use the field as the
     * index and the data as the values. All fields returned by getFields() should be returned by this function.
     *
     * For example, this function might return array('zip' => '53222', 'state' => 'WI', 'country' => 'United States')
     *
     * @param string $ipAddress IP address to lookup location for
     * @return array|false
     */
    public function getLocation($ipAddress);

    /**
     * Saves the location provider config
     * @param array $config Array of config options, usually the same as $_POST
     * @return void
     */
    public function saveConfig($config);

    /**
     * Called when the setup form is displayed.
     * @return null|string
     */
    public function renderSetupForm();

}